@@ -136,7 +136,7 @@ class __internal__:
         Arguments:
             configuration_info: the configuration information of transformer
         Return:
-            Returns True if metadata is required (the default is that it's required), or False if not
+            Returns True if metadata is required (the default is that it's not required), or False if not
         """
         # Disable the following check since it's not a valid test here
         # (metadata_needed is an optional variable)
@@ -144,12 +144,17 @@ class __internal__:
 
         # If we have a variable defined, check the many ways of determining False
         if hasattr(configuration_info, 'metadata_needed'):
-            if not configuration_info.metadata_needed:
-                return False
+            if configuration_info.metadata_needed:
+                return True
             if isinstance(configuration_info.metadata_needed, str):
-                if configuration_info.metadata_needed.lower().strip() == 'false':
-                    return False
-        return True
+                if configuration_info.metadata_needed.lower().strip() == 'true':
+                    return True
+            # if not configuration_info.metadata_needed:
+            #     return False
+            # if isinstance(configuration_info.metadata_needed, str):
+            #     if configuration_info.metadata_needed.lower().strip() == 'false':
+            #         return False
+        return False
 
     @staticmethod
     def load_metadata_files(metadata_files: list) -> dict:
@@ -397,7 +402,7 @@ def do_work(parser: argparse.ArgumentParser, configuration_info: Configuration,
     # Check that we have mandatory metadata
     if not args.metadata and __internal__.check_metadata_needed(configuration_info):
         result = __internal__.handle_error(-1, "No metadata paths were specified.")
-    else:
+    if args.metadata:
         md_results = __internal__.load_metadata_files(args.metadata)
         if 'metadata' in md_results:
             result = __internal__.perform_processing(transformer_instance, algorithm_instance, args, md_results['metadata'])
